@@ -57,24 +57,11 @@ while (time < $s) {
 } ## end while (time < $s)
 
 print_it($F, 'Line Test');
-for (my $l = $F->{'Y_CLIP'} ; $l < $YY ; $l += 8) {
+$s = time + $factor;
+while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->line({'x' => 0, 'y' => $l, 'xx' => $XX, 'yy' => $l});
-
-    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->line({'x' => 0, 'y' => $l, 'xx' => $l, 'yy' => $F->{'Y_CLIP'}});
-
-    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->line({'x' => $XX, 'y' => $l, 'xx' => $XX - $l, 'yy' => $F->{'Y_CLIP'}});
-
-    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->line({'x' => $XX, 'y' => $YY - $l, 'xx' => $XX - $l, 'yy' => $F->{'Y_CLIP'}});
-
+    $F->line({'x' => rand($XX), 'y' => rand($YY), 'xx' => rand($XX), 'yy' => rand($YY)});
 } ## end for (my $l = $F->{'Y_CLIP'...})
-for (my $l = 0 ; $l < $XX ; $l += 8) {
-    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->line({'x' => $l, 'y' => $F->{'Y_CLIP'}, 'xx' => $l, 'yy' => $YY});
-}
 
 print_it($F, 'Box Test');
 $s = time + $factor;
@@ -219,14 +206,14 @@ print_it($F, 'Circle Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->circle({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_x)});
+    $F->circle({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y)});
 }
 
 print_it($F, 'Filled Circle Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->circle({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_x), 'filled' => 1});
+    $F->circle({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y), 'filled' => 1});
 }
 
 print_it($F, 'Vertical Gradient Circle Test');
@@ -237,7 +224,7 @@ while (time < $s) {
         {
             'x'        => rand($XX),
             'y'        => rand($YY),
-            'radius'   => rand($center_x),
+            'radius'   => rand($center_y),
             'filled'   => 1,
             'gradient' => {
                 'start' => {
@@ -263,7 +250,7 @@ while (time < $s) {
         {
             'x'        => rand($XX),
             'y'        => rand($YY),
-            'radius'   => rand($center_x),
+            'radius'   => rand($center_y),
             'filled'   => 1,
             'gradient' => {
                 'direction' => 'horizontal',
@@ -286,7 +273,7 @@ print_it($F, 'Arc Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->arc({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_x), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
+    $F->arc({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
 }
 
 print_it($F, 'Poly Arc Test');
@@ -304,7 +291,7 @@ while (time < $s) {
 }
 
 print_it($F, 'Vertical Gradient Filled Pie Test');
-$s = time + ($factor * 2);
+$s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->filled_pie(
@@ -331,7 +318,7 @@ while (time < $s) {
 } ## end while (time < $s)
 
 print_it($F, 'Horizontal Gradient Filled Pie Test');
-$s = time + ($factor * 2);
+$s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->filled_pie(
@@ -650,6 +637,17 @@ while (time < $s) {
     $image->{'y'} = abs(rand($YY - $image->{'height'}));
     $F->blit_write($image);
 }
+# sleep $factor;
+
+print_it($F, 'Testing Monochrome Image blitting');
+
+$image->{'image'} = $F->monochrome({'image' => $image->{'image'}, 'bits' => $F->{'BITS'}});
+$s = time + $factor;
+while (time < $s) {
+    $image->{'x'} = abs(rand($XX - $image->{'width'}));
+    $image->{'y'} = abs(rand($YY - $image->{'height'}));
+    $F->blit_write($image);
+}
 
 $F->clip_reset();
 $F->cls('ON');
